@@ -1,4 +1,4 @@
-# Copyright 2016-2020 The Van Valen Lab at the California Institute of
+# Copyright 2016-2021 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -139,7 +139,7 @@ def bn_feature_net_2D(receptive_field=61,
             x.append(ZeroPadding2D(padding=(win, win))(x[-1]))
 
     if location:
-        x.append(Location2D(in_shape=tuple(x[-1].shape.as_list()[1:]))(x[-1]))
+        x.append(Location2D()(x[-1]))
         x.append(Concatenate(axis=channel_axis)([x[-2], x[-1]]))
 
     layers_to_concat = []
@@ -388,7 +388,7 @@ def bn_feature_net_3D(receptive_field=61,
             x.append(ZeroPadding3D(padding=(win_z, win, win))(x[-1]))
 
     if location:
-        x.append(Location3D(in_shape=tuple(x[-1].shape.as_list()[1:]))(x[-1]))
+        x.append(Location3D()(x[-1]))
         x.append(Concatenate(axis=channel_axis)([x[-2], x[-1]]))
 
     layers_to_concat = []
@@ -605,7 +605,8 @@ def siamese_model(input_shape=None,
             return (None, 2)
         elif feature == 'neighborhood':
             return (None, 2 * neighborhood_scale_size + 1,
-                    2 * neighborhood_scale_size + 1, 1)
+                    2 * neighborhood_scale_size + 1,
+                    input_shape[-1])
         elif feature == 'regionprop':
             return (None, 3)
         else:
@@ -651,10 +652,7 @@ def siamese_model(input_shape=None,
             N_layers_og = np.int(np.floor(np.log2(2 * neighborhood_scale_size + 1)))
             feature_extractor_neighborhood = Sequential()
             feature_extractor_neighborhood.add(
-                InputLayer(input_shape=(None,
-                                        2 * neighborhood_scale_size + 1,
-                                        2 * neighborhood_scale_size + 1,
-                                        1))
+                InputLayer(input_shape=shape)
             )
             for layer in range(N_layers_og):
                 feature_extractor_neighborhood.add(Conv3D(64, (1, 3, 3),
@@ -679,10 +677,11 @@ def siamese_model(input_shape=None,
 
     if K.image_data_format() == 'channels_first':
         channel_axis = 1
-        input_shape = tuple([input_shape[0], None] + list(input_shape[1:]))
+        raise ValueError('siamese_model: Only channels_last is supported.')
     else:
         channel_axis = -1
-        input_shape = tuple([None] + list(input_shape))
+
+    input_shape = tuple([None] + list(input_shape))
 
     features = sorted(features)
 
