@@ -1,4 +1,4 @@
-# Copyright 2016-2020 The Van Valen Lab at the California Institute of
+# Copyright 2016-2021 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -57,11 +57,11 @@ def create_pyramid_level(backbone_input,
     """Create a pyramid layer from a particular backbone input layer.
 
     Args:
-        backbone_input (layer): Backbone layer to use to create they pyramid
-            layer
+        backbone_input (tensorflow.keras.Layer): Backbone layer to use to
+            create they pyramid layer.
         upsamplelike_input (tensor): Optional input to use
-            as a template for shape to upsample to
-        addition_input (layer): Optional layer to add to
+            as a template for shape to upsample to.
+        addition_input (tensorflow.keras.Layer): Optional layer to add to
             pyramid layer after convolution and upsampling.
         upsample_type (str): Choice of upsampling methods
             from ``['upsamplelike','upsampling2d','upsampling3d']``.
@@ -446,7 +446,7 @@ def __create_semantic_head(pyramid_dict,
             ``['upsamplelike','upsampling2d', 'upsampling3d']``
 
     Returns:
-        tensorflow.keras.layers.Layer: The semantic segmentation head
+        tensorflow.keras.Layer: The semantic segmentation head
     """
     # Check input to ndims
     if ndim not in {2, 3}:
